@@ -4,6 +4,7 @@ try:
     from _thread import get_ident
 except ImportError:
     from thread import get_ident
+from threading import enumerate as enumerate_threads
 try:
     from urllib import quote
 except ImportError:
@@ -33,16 +34,13 @@ class SQLiteConnection(DBAPI):
 
     def __init__(self, filename, autoCommit=1, **kw):
         drivers = kw.pop('driver', None) or \
-            'supersqlite,pysqlite2,sqlite3,sqlite'
+            'pysqlite2,sqlite3,sqlite'
         for driver in drivers.split(','):
             driver = driver.strip()
             if not driver:
                 continue
             try:
-                if driver == 'supersqlite':
-                    from supersqlite import sqlite3 as sqlite
-                    self.using_sqlite2 = True
-                elif driver in ('sqlite2', 'pysqlite2'):
+                if driver in ('sqlite2', 'pysqlite2'):
                     from pysqlite2 import dbapi2 as sqlite
                     self.using_sqlite2 = True
                 elif driver == 'sqlite3':
@@ -54,7 +52,7 @@ class SQLiteConnection(DBAPI):
                 else:
                     raise ValueError(
                         'Unknown SQLite driver "%s", '
-                        'expected supersqlite, pysqlite2, sqlite3 '
+                        'expected pysqlite2, sqlite3 '
                         'or sqlite' % driver)
             except ImportError:
                 pass
@@ -150,6 +148,7 @@ class SQLiteConnection(DBAPI):
             self._connectionNumbers[id(conn)] = self._connectionCount
             self._connectionCount += 1
             return conn
+        self._releaseUnusedConnections()
         threadid = get_ident()
         if (self._pool is not None and threadid in self._threadPool):
             conn = self._threadPool[threadid]
@@ -181,6 +180,9 @@ class SQLiteConnection(DBAPI):
         else:
             if self._pool and conn in self._pool:
                 self._pool.remove(conn)
+            if threadid:
+                del self._threadOrigination[id(conn)]
+                del self._threadPool[threadid]
             conn.close()
 
     def _setAutoCommit(self, conn, auto):
@@ -211,9 +213,23 @@ class SQLiteConnection(DBAPI):
         conn.text_factory = str  # Convert text data to str, not unicode
         return conn
 
+    def _releaseUnusedConnections(self):
+        """Release connections from threads that're no longer active"""
+        thread_ids = set(t.ident for t in enumerate_threads())
+        tp_set = set(self._threadPool)
+        unused_connections = [
+            self._threadPool[tid] for tid in tp_set - thread_ids
+        ]
+        for unused_connection in unused_connections:
+            try:
+                self.releaseConnection(unused_connection, explicit=True)
+            except self.module.ProgrammingError:
+                pass  # Ignore error in `conn.close()` from a different thread
+
     def close(self):
         DBAPI.close(self)
         self._threadPool = {}
+        self._threadOrigination = {}
         if self._memory:
             self._memoryConn.close()
             self.makeMemoryConnection()
@@ -295,8 +311,11 @@ class SQLiteConnection(DBAPI):
         return self._createIDColumn(soClass.sqlmeta)
 
     def _createIDColumn(self, sqlmeta):
-        if sqlmeta.idType == str:
+        if sqlmeta.idType is str:
             return '%s TEXT PRIMARY KEY' % sqlmeta.idName
+        if sqlmeta.idType is not int:
+            raise TypeError('sqlmeta.idType must be int or str, not %r'
+                            % sqlmeta.idType)
         return '%s INTEGER PRIMARY KEY AUTOINCREMENT' % sqlmeta.idName
 
     def joinSQLType(self, join):
